#
# spec file for package miller
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           miller
Version:        6.13.0+git20241006.7a0320fc2
Release:        1.3
Summary:        Name-indexed data processing tool
# c/lib/netbsd_strptime.c is BSD-4-Clause
License:        BSD-2-Clause AND BSD-4-Clause
Group:          Productivity/Text/Utilities
URL:            http://johnkerl.org/miller/doc
Source0:        https://github.com/johnkerl/miller/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Patch0:         update-VERSION.diff
Patch1:         buildmode-pie.diff
### Temporary until go1.22 is default
BuildRequires:  golang-packaging
#BuildRequires:  go >= 1.22
#####
BuildRequires:  gcc
BuildRequires:  systemd-rpm-macros
# Switched to a golang build sometime after 5.10.3
#BuildRequires:  automake
#BuildRequires:  flex >= 2.5.35
#BuildRequires:  libtool

%description
Miller (mlr) allows name-indexed data such as CSV and JSON files to be
processed with functions equivalent to sed, awk, cut, join, sort etc. It can
convert between formats, preserves headers when sorting or reversing, and
streams data where possible so its memory requirements stay small. It works
well with pipes and can feed "tail -f".

%prep
%setup -q -a 1
%patch -P 0
%if "%{_arch}" != "ppc64"
%patch -P 1
%endif
# Not sure if this is still required
#%%ifarch %%ix86
#sed -e 's/-pg//' -i c/Makefile.am
#%%endif

%build
%make_build

%install
%make_install PREFIX=%{_prefix}
# Add provided example.csv
cp -v %{_builddir}/%{name}-%{version}/docs/src/example.csv %{_builddir}/%{name}-%{version}

%files
%license LICENSE.txt
%doc README.md example.csv
%{_bindir}/mlr
%{_mandir}/man1/mlr.1%{ext_man}

%changelog
* Sun Oct  6 2024 scott.bradnick@suse.com
- Update to version 6.13.0+git20241006.7a0320fc2:
  * Typo fix: programmatically (#1679)
  * make dev for previous commit
  * 6.13.0-dev
  * 6.13 release docs
  * trying again with go version / go mod tidy
  * go mod tidy requires go 1.20
  * miller 6.13.0
  * Fix minor typo (#1673)
  * Fix 1668 error-source (#1672)
  * Characters to be removed (#1668)
  * Bump github/codeql-action from 3.26.10 to 3.26.11 (#1669)
  * Update source material for #1665 (#1666)
  * Update reference-verbs.md (#1665)
  * Bump github/codeql-action from 3.26.9 to 3.26.10 (#1664)
  * Bump actions/checkout from 4.1.7 to 4.2.0 (#1662)
  * Bump github/codeql-action from 3.26.8 to 3.26.9 (#1660)
  * Bump github.com/klauspost/compress from 1.17.9 to 1.17.10 (#1659)
* Fri Sep 20 2024 scott.bradnick@suse.com
- Update to version 6.12.0+git20240920.7afa99dec:
  * Compiling on newer go versions doesn't work (#1655)
  * The package version must match the major tag version (#1654)
  * Bump github/codeql-action from 3.26.7 to 3.26.8 (#1652)
  * Fix local time when TZ is not set (#1649)
  * Bump github/codeql-action from 3.26.6 to 3.26.7 (#1648)
  * Bump golang.org/x/term from 0.23.0 to 0.24.0 (#1642)
  * Bump golang.org/x/text from 0.17.0 to 0.18.0 (#1641)
  * Bump actions/upload-artifact from 4.3.6 to 4.4.0 (#1640)
  * Bump github/codeql-action from 3.26.5 to 3.26.6 (#1638)
  * Bump github.com/lestrrat-go/strftime from 1.0.6 to 1.1.0 (#1637)
  * Enable admonition extension (#1636)
  * Source-file update for PR 1634 (#1635)
  * A note about positional field names (#1634)
  * Update extra.css (#1633)
  * To have edit and copy code in each page (#1632)
  * To realize which chapter and section are active (#1631)
  * Bump github/codeql-action from 3.26.4 to 3.26.5 (#1630)
  * Error in `splita`/`splitax` when field contains a single non-string value (#1629)
  * Misc. codespell findings (#1628)
  * Fix prepipe handling when filenames have whitespace (#1627)
  * Fix binary data in JSON output (#1626)
  * Bump github/codeql-action from 3.26.3 to 3.26.4 (#1624)
  * Bump github/codeql-action from 3.26.2 to 3.26.3 (#1623)
* Mon Aug 19 2024 scott.bradnick@suse.com
- Update to version 6.12.0+git20240819.bdd26736a:
  * Bump codespell-project/actions-codespell from 2.0 to 2.1 (#1622)
  * RS aliases for ASCII top-of-table control characters are misnamed (#1620)
  * Bump github/codeql-action from 3.26.1 to 3.26.2 (#1617)
  * Bump github/codeql-action from 3.26.0 to 3.26.1 (#1615)
  * lib/regex: use string version of regexp methods to reduce allocs (#1614)
  * Bump golang.org/x/sys from 0.23.0 to 0.24.0 (#1613)
  * Bump golang.org/x/text from 0.16.0 to 0.17.0 (#1611)
  * Bump github/codeql-action from 3.25.15 to 3.26.0 (#1610)
  * Bump actions/upload-artifact from 4.3.5 to 4.3.6 (#1609)
  * Bump golang.org/x/term from 0.22.0 to 0.23.0 (#1612)
* Wed Aug 14 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding update-VERSION.diff file so 'osc service mr' updates the version
  using 'replace_using_env'
* Mon Aug  5 2024 scott.bradnick@suse.com
- Update to version 6.12.0+git20240805.93574580f:
  * Bump actions/upload-artifact from 4.3.4 to 4.3.5 (#1606)
  * Bump golang.org/x/sys from 0.22.0 to 0.23.0 (#1605)
  * Bump github/codeql-action from 3.25.14 to 3.25.15 (#1604)
  * Bump github/codeql-action from 3.25.13 to 3.25.14 (#1603)
  * Bump github/codeql-action from 3.25.12 to 3.25.13 (#1602)
  * Bump github/codeql-action from 3.25.11 to 3.25.12 (#1598)
  * Bump actions/setup-go from 5.0.1 to 5.0.2 (#1597)
* Mon Jul  8 2024 scott.bradnick@suse.com
- Update to version 6.12.0+git20240708.1029c960:
  * Bump actions/upload-artifact from 4.3.3 to 4.3.4 (#1596)
  * Bump golang.org/x/term from 0.21.0 to 0.22.0 (#1594)
  * Bump golang.org/x/sys from 0.21.0 to 0.22.0 (#1595)
  * Bump github/codeql-action from 3.25.10 to 3.25.11 (#1593)
  * Bump github/codeql-action from 3.25.9 to 3.25.10 (#1588)
  * Bump github/codeql-action from 3.25.8 to 3.25.9 (#1587)
  * Bump actions/checkout from 4.1.6 to 4.1.7 (#1586)
* Wed Jun 12 2024 scott.bradnick@suse.com
- Update to version 6.12.0+git20240612.97c299a4:
  * Bump github.com/klauspost/compress from 1.17.8 to 1.17.9 (#1585)
  * Be smarter about auto-unflatten (#1584)
  * Bash process substitution not working with `put -f` (#1583)
  * Note IANA TSV support (#1582)
  * On-line help for `mlr summary --transpose` (#1581)
  * Support `$NO_COLOR` (#1580)
  * fraction bugfix (#1579)
  * Bump golang.org/x/term from 0.20.0 to 0.21.0 (#1577)
  * Bump golang.org/x/sys from 0.20.0 to 0.21.0 (#1578)
  * Bump golang.org/x/text from 0.15.0 to 0.16.0 (#1576)
  * Bump github/codeql-action from 3.25.7 to 3.25.8 (#1575)
  * Bump goreleaser/goreleaser-action from 5.1.0 to 6.0.0 (#1574)
  * Bump github/codeql-action from 3.25.6 to 3.25.7 (#1570)
  * --- (#1568)
  * Bump github/codeql-action from 2.13.4 to 3.25.5 (#1567)
  * Bump actions/checkout from 4.1.5 to 4.1.6 (#1566)
  * Bump goreleaser/goreleaser-action from 5.0.0 to 5.1.0 (#1563)
  * Add `mad` accumulator for `stats1` DSL function (#1561)
  * Add a `stat` DSL function (#1560)
* Tue May  7 2024 scott.bradnick@suse.com
- Update to version 6.12.0+git20240507.956e65c1:
  * Bump actions/checkout from 4.1.4 to 4.1.5 (#1557)
  * Bump golang.org/x/term from 0.19.0 to 0.20.0 (#1555)
  * Bump golang.org/x/text from 0.14.0 to 0.15.0 (#1556)
  * Bump golang.org/x/sys from 0.19.0 to 0.20.0 (#1554)
  * Bump actions/setup-go from 5.0.0 to 5.0.1 (#1553)
  * Bump actions/checkout from 4.1.3 to 4.1.4 (#1552)
  * Bump actions/upload-artifact from 4.3.2 to 4.3.3 (#1551)
  * Fix mismatched method names in comments (#1549)
  * Bump actions/checkout from 4.1.2 to 4.1.3 (#1550)
  * Try to build readthedocs `.epub` and `.pdf` (#1548)
  * Bump actions/upload-artifact from 4.3.1 to 4.3.2 (#1547)
  * chore: fix function name in comment (#1543)
  * Fix typo in online help for `--no-jlistwrap` (#1541)
  * Bump github.com/klauspost/compress from 1.17.7 to 1.17.8 (#1538)
  * Bump golang.org/x/term from 0.18.0 to 0.19.0 (#1536)
  * Bump actions/cache from 4.0.1 to 4.0.2 (#1532)
* Sun Mar 17 2024 scott.bradnick@suse.com
- Update to version 6.12.0+git20240316.f6e378c8:
  * build previous
  * 6.12.0 doc link
  * miller 6.12.0
  * Add descriptions for `put` and `filter` verbs (#1529)
  * Avoid spurious `[]` on JSON output in some cases (#1528)
  * Bump actions/checkout from 4.1.1 to 4.1.2 (#1526)
  * Bump golang.org/x/term from 0.17.0 to 0.18.0 (#1522)
  * Bump golang.org/x/sys from 0.17.0 to 0.18.0 (#1521)
  * Bump github.com/stretchr/testify from 1.8.4 to 1.9.0 (#1516)
* Fri Mar  1 2024 scott.bradnick@suse.com
- Update to version 6.11.0+git20240301.e528b9e11:
  * Bump actions/cache from 4.0.0 to 4.0.1 (#1511)
  * Improved file-not-found handling (#1508)
  * python/make-tsv.py
  * Enable record-hashing by default (#1507)
  * Miller produces no output on TSV with > 64K characters per line (#1505)
  * Separate out `ILineReader` abstraction (#1504)
  * Bump github.com/klauspost/compress from 1.17.6 to 1.17.7 (#1502)
  * Support thousands separator in `fmtnum` (#1499)
  * make dev artifacts for sparsify
  * mlr sparsify (#1498)
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Feb  8 2024 scott.bradnick@suse.com
- Update to version 6.11.0+git20240208.cd6d42736:
  * Bump golang.org/x/term from 0.16.0 to 0.17.0 (#1494)
  * Bump github.com/klauspost/compress from 1.17.5 to 1.17.6 (#1492)
  * Bump actions/upload-artifact from 4.3.0 to 4.3.1 (#1491)
  * sort-link doc update
  * Bump github.com/klauspost/compress from 1.16.7 to 1.17.5 (#1486)
  * 6.11.0-dev (#1484)
  * Bump actions/upload-artifact from 4.2.0 to 4.3.0 (#1483)
  * update release docs
* Tue Jan 23 2024 scott.bradnick@suse.com
- Update to version 6.11.0+git20240123.6f24fb39:
  * miller.spec typofix
  * Miller 6.11.0 (#1481)
  * Implement all/by-regex field selection (`-a`/`-r`) for `mlr sub`, `gsub`, and `ssub` (#1480)
* Mon Jan 22 2024 scott.bradnick@suse.com
- Update to version 6.10.0+git20240121.81d11365:
  * `mlr reorder` with regex support [WIP] (#1473)
  * Auto-unsparsify CSV and TSV on output (#1479)
  * Support markdown format on input (#1478)
  * Don't run regression tests twice in GitHub CI (#1477)
  * Fix typos in tests for PPRINT barred input (#1476)
* Sat Jan 20 2024 scott.bradnick@suse.com
- Update to version 6.10.0+git20240120.bfc829a3:
  * Internal name-neatens (#1475)
  * typofix
  * Support PPRINT barred input (#1472)
  * Bump actions/upload-artifact from 4.1.0 to 4.2.0 (#1471)
  * Bump actions/cache from 3.3.3 to 4.0.0 (#1470)
  * Bump actions/upload-artifact from 4.0.0 to 4.1.0 (#1469)
  * Bump actions/cache from 3.3.2 to 3.3.3 (#1468)
* Fri Jan  5 2024 scott.bradnick@suse.com
- Update to version 6.10.0+git20240105.664a84fa:
  * Bump golang.org/x/term from 0.15.0 to 0.16.0 (#1466)
  * Have `clean_whitespace` re-run type inference (#1464)
  * Fix #1462: remove limit of 1000 on dedupe field names (#1463)
  * On-line help info for `mlr join --lk ""` (#1458)
  * Implement `mlr uniq -x` (#1457)
  * Replace deprecated `io/ioutil` functions (#1452)
  * New `strmatch`/`strmatchx` DSL functions (#1448)
  * make docs
  * Document and unit-test regex-capture reset logic (#1451)
  * mlr --norc cat was erroring (#1450)
  * Preserve regex captures across stack frames (#1447)
  * Rename internal regex functions (#1446)
  * Bump actions/upload-artifact from 3.1.3 to 4.0.0 (#1445)
  * release docs including 6.9.0 and 6.10.0
  * 6.10.0-dev
* Thu Dec 14 2023 scott.bradnick@suse.com
- Update to version 6.10.0+git20231213.c680f331:
  * add doc note re snag found on last commit
  * update go 1.18 -> 1.19 in more spots
  * update path in create_release_tarball
  * miller 6.10.0 (#1442)
  * neaten
  * Update to Go 1.19 (#1441)
  * Bump actions/setup-go from 4.1.0 to 5.0.0 (#1436)
  * Absent variable on left side of boolean OR (`||`) expression makes it absent (#1434)
  * Bump golang.org/x/term from 0.14.0 to 0.15.0 (#1432)
  * Fix ragged-CSV auto-pad (#1428)
  * Add a `--files` option (#1426)
  * JSONL output does not properly handle keys with quotes (#1425)
* Wed Nov  8 2023 scott.bradnick@suse.com
- Update to version 6.9.0+git20231108.f2a9ae5c:
  * Bump golang.org/x/term from 0.13.0 to 0.14.0 (#1423)
  * Bump golang.org/x/sys from 0.13.0 to 0.14.0 (#1420)
  * Bump golang.org/x/text from 0.13.0 to 0.14.0 (#1419)
  * transformers/grep: avoid allocations with `(*regexp.Regexp).MatchString` (#1416)
  * neaten README.md
  * add `winget` to README (#1414)
  * Bump actions/checkout from 4.1.0 to 4.1.1 (#1412)
  * Bump github.com/mattn/go-isatty from 0.0.19 to 0.0.20 (#1411)
  * Bump golang.org/x/term from 0.12.0 to 0.13.0 (#1404)
  * Bump actions/checkout from 4.0.0 to 4.1.0 (#1400)
  * Bump goreleaser/goreleaser-action from 4.6.0 to 5.0.0 (#1396)
  * Include `null` in `any` typemask (#1395)
  * Name-neaten for #1392 (#1393)
  * Better API example (#1392)
  * doc tweaks
  * Export library code in `pkg/` (#1391)
  * Bump actions/cache from 3.3.1 to 3.3.2 (#1390)
  * Bump actions/upload-artifact from 3.1.2 to 3.1.3 (#1387)
  * Bump goreleaser/goreleaser-action from 4.4.0 to 4.6.0 (#1385)
  * Bump actions/checkout from 3.6.0 to 4.0.0 (#1383)
  * Bump golang.org/x/term from 0.11.0 to 0.12.0 (#1380)
  * Bump golang.org/x/sys from 0.11.0 to 0.12.0 (#1381)
  * Bump golang.org/x/text from 0.12.0 to 0.13.0 (#1382)
  * `macos` -> `darwin` in `.goreleaser.yml` (#1377)
  * Remove `replacements` from `.goreleaser.yaml` (#1376)
* Thu Aug 31 2023 scott.bradnick@suse.com
- Update to version 6.9.0+git20230831.acc10cdc:
  * miller 6.9.0
  * Fatal-on-data-error `mlr -x` option (#1373)
  * Typofix in `uif`/`uof` percentiles (#1375)
  * docmods for typofix
  * typofix
  * New `contains` DSL function (#1374)
  * Update 2015-era Python sketch to Python 3 (#1372)
  * Treat empty like absent in `+` `-` `*` (#1371)
  * typofix
  * Summing up empty data (#1370)
  * doc-neaten
  * make dev
  * typofix
  * more doc-neatens for percentiles on-line help
  * neaten online help for the percentiles function
  * typofixes
  * DSL functions for summary stats over arrays / maps (#1364)
  * Bump actions/checkout from 3.5.3 to 3.6.0 (#1369)
  * make-dev artifacts from previous commit
  * 1366 follow-up
  * filename options for `split` (iss. #1365) (#1366)
  * Remove redundant nil check (#1367)
  * fix codespell ci
  * fix some broken links in README-dev.md
  * Can't use ${field_name} if it contains UTF-8 characters also encodeable as Latin-1 (#1363)
  * Do wildcard globbing on Windows (#1362)
  * `sub`, `gsub`, and `ssub` verbs (#1361)
  * Support ZSTD compression in-process (#1360)
  * Support comments in `mlr -s` files (#1359)
  * Bump golang.org/x/term from 0.10.0 to 0.11.0 (#1348)
  * Bump goreleaser/goreleaser-action from 4.3.0 to 4.4.0 (#1354)
  * Small typos in documentation of `mlr nest` (#1352)
  * Bump actions/setup-go from 4.0.1 to 4.1.0 (#1351)
  * Bump golang.org/x/text from 0.11.0 to 0.12.0 (#1349)
  * Bump golang.org/x/sys from 0.10.0 to 0.11.0 (#1347)
  * Update Fedora link (#1339)
  * Bump golang.org/x/term from 0.9.0 to 0.10.0 (#1338)
  * Bump golang.org/x/sys from 0.9.0 to 0.10.0 (#1336)
  * Bump golang.org/x/text from 0.10.0 to 0.11.0 (#1337)
  * Add `%%s` format specifier for `strftime` (#1335)
  * Add `%%N` and `%%O` for `strfntime` (#1334)
  * Add empty-key check to `mlr check` (#1330)
  * todo
  * Add DSL functions for integer nanoseconds since the epoch (#1326)
  * Bump golang.org/x/text from 0.9.0 to 0.10.0 (#1322)
  * Bump goreleaser/goreleaser-action from 4.2.0 to 4.3.0 (#1320)
  * Bump golang.org/x/term from 0.8.0 to 0.9.0 (#1321)
  * Bump github/codeql-action from 2.3.6 to 2.13.4 (#1318)
  * Bump actions/checkout from 3.5.2 to 3.5.3 (#1319)
  * Fix `mlr grep` docs re OFS/OPS (#1309)
* Mon Jun  5 2023 scott.bradnick@suse.com
- Update to version 6.8.0+git20230604.4050f566:
  * fix mis-spelling for head docs
  * Update readthedocs notes in the how-to-release page (#1308)
  * release 6.8.0 docs
  * post-6.8.0
  * Update go version in .github/workflows/release.yml
  * go mod tidy
  * miller 6.8.0
  * Unify the `case` verb, and add options (#1306)
  * Values-only `-a` option for `mlr grep` (#1305)
  * Bump github/codeql-action from 2.3.5 to 2.3.6 (#1303)
  * Bump github.com/stretchr/testify from 1.8.3 to 1.8.4 (#1301)
  * Bump github/codeql-action from 2.3.4 to 2.3.5 (#1300)
  * Bump github/codeql-action from 2.3.3 to 2.3.4 (#1299)
  * Bump github.com/mattn/go-isatty from 0.0.18 to 0.0.19 (#1296)
  * Bump github.com/stretchr/testify from 1.8.2 to 1.8.3 (#1295)
  * Bump actions/setup-go from 4.0.0 to 4.0.1 (#1294)
  * Let `mlr help` take pre-flags, such as `--always-color` (#1292)
  * New `mlr json-parse -k` flag (#1291)
  * Bump golang.org/x/term from 0.7.0 to 0.8.0 (#1285)
  * Bump github/codeql-action from 2.3.2 to 2.3.3 (#1284)
* Wed May  3 2023 scott.bradnick@suse.com
- Update to version 6.7.0+git20230501.6c86ef19:
  * Bump codespell-project/actions-codespell (#1282)
  * Bump github/codeql-action from 2.3.1 to 2.3.2 (#1279)
  * Bump github/codeql-action from 2.3.0 to 2.3.1 (#1277)
  * Bump github/codeql-action from 2.2.12 to 2.3.0 (#1274)
  * Implement `--csv-trim-leading-space` flag (#1272)
  * Fix precedence of coalesce operators `??` and `???` (#1270)
  * Treaet data-file numbers with leading + as numeric (#1269)
  * Bump github/codeql-action from 2.2.11 to 2.2.12 (#1265)
  * Bump actions/checkout from 3.5.1 to 3.5.2 (#1264)
  * Bump actions/checkout from 3.5.0 to 3.5.1 (#1263)
  * Bump github/codeql-action from 2.2.10 to 2.2.11 (#1261)
  * Bump github/codeql-action from 2.2.9 to 2.2.10 (#1259)
  * Bump golang.org/x/term from 0.6.0 to 0.7.0 (#1256)
  * Fix typo (#1252)
  * Bump codespell-project/actions-codespell (#1253)
  * Better error message on unparseable TZ environment variable (#1249)
* Wed Mar 29 2023 scott.bradnick@suse.com
- Update to version 6.7.0+git20230328.dc14420f:
  * Bump github/codeql-action from 2.2.8 to 2.2.9 (#1250)
  * Fix issue links in README-dev.md (#1248)
  * `index` DSL function [WIP] (#1247)
  * Bump github.com/mattn/go-isatty from 0.0.17 to 0.0.18 (#1243)
  * Bump golang.org/x/term from 0.0.0-20210927222741-03fcf44c2211 to 0.6.0 (#1222)
  * Bump minimum compiler version from Go 1.15 to 1.18 (#1246)
  * Bump actions/checkout from 3.4.0 to 3.5.0 (#1245)
  * Add optional second base argument to `int` DSL function (#1244)
  * Bump github/codeql-action from 2.2.7 to 2.2.8 (#1242)
  * Bump actions/checkout from 3.3.0 to 3.4.0 (#1234)
  * Bump actions/setup-go from 3.5.0 to 4.0.0 (#1233)
  * Bump github/codeql-action from 2.2.6 to 2.2.7 (#1232)
  * Bump actions/cache from 3.2.6 to 3.3.1 (#1229)
  * Bump github/codeql-action from 2.2.5 to 2.2.6 (#1230)
  * Add `mlr step -a rprod` for running products (#1228)
  * Label head docs as "Miller Dev Documentation"
  * doc note for #1218
  * Run go mod tidy (#1220)
  * Include tools in the release tarball (#1221)
  * Add new `upcase` and `downcase` verbs (#1217)
  * Docs re `tail -f` and `--records-per-batch 1` (#1218)
  * typofix
  * Fix bug on DSL comment with no final newline (#1216)
  * release docs
  * build artifacts
  * miller 6.7.0-dev
  * miller 6.7.0
  * Support more backslashed special characters in DSL strings (#1212)
  * unit-test files
  * fix build error
  * Unit-test updates
  * tools/build-dsl artifacts
  * Update DSL-build instructions
  * go.mod go.sum
  * BNF mod for `\^` `\$` et al.
  * --ofmte, --ofmtf, --ofmtg (#1206)
  * Bump github/codeql-action from 2.2.4 to 2.2.5 (#1207)
  * Bump github.com/stretchr/testify from 1.8.1 to 1.8.2 (#1208)
  * New `leftpad` and `rightpad` DSL functions (#1205)
  * Bump golang.org/x/sys in /cmd/experiments/cli_parser (#1203)
  * Bump actions/cache from 3.2.5 to 3.2.6 (#1196)
  * Bump github/codeql-action from 2.2.3 to 2.2.4 (#1193)
  * Bump github/codeql-action from 2.2.1 to 2.2.3 (#1191)
  * Bump actions/cache from 3.2.4 to 3.2.5 (#1192)
  * Bump actions/cache from 3.2.3 to 3.2.4 (#1186)
  * Bump goreleaser/goreleaser-action from 4.1.1 to 4.2.0 (#1187)
  * Bump goreleaser/goreleaser-action from 4.1.0 to 4.1.1 (#1185)
  * Complete #1181 (#1184)
  * Bump github/codeql-action from 2.1.39 to 2.2.1 (#1183)
  * Fixed missing double quote in documentation sample (#1181)
  * Bump github/codeql-action from 2.1.38 to 2.1.39 (#1179)
  * Bump github/codeql-action from 2.1.37 to 2.1.38 (#1176)
  * Bump actions/upload-artifact from 3.1.1 to 3.1.2 (#1175)
  * Bump actions/cache from 3.2.2 to 3.2.3 (#1174)
  * Bump actions/checkout from 3.2.0 to 3.3.0 (#1173)
  * Bump codespell-project/actions-codespell (#1172)
  * Add Go LICENSE file (#1171)
* Mon Jan  2 2023 scott.bradnick@suse.com
- Update to version 6.6.0+git20230101.7495a8845:
  * link to 6.6.0 docs
  * doc-neaten
  * post-6.6.0
  * 6.6.0 (#1169)
  * Fix #1164: regression on CSV blank-line handling (#1168)
  * mlr unspace verb (#1167)
  * Add doc info on DSL code-comment syntax (#1165)
  * Fix #1102 (#1163)
  * Fix #1146 (#1157)
  * Bump github.com/mattn/go-isatty from 0.0.16 to 0.0.17 (#1162)
  * Bump actions/cache from 3.2.1 to 3.2.2 (#1160)
  * Bump actions/cache from 3.2.0 to 3.2.1 (#1156)
  * Bump actions/cache from 3.0.11 to 3.2.0 (#1155)
  * Bump github/codeql-action from 2.1.36 to 2.1.37 (#1151)
  * Bump actions/setup-go from 3.4.0 to 3.5.0 (#1148)
  * Bump goreleaser/goreleaser-action from 3.2.0 to 4.1.0 (#1147)
  * Bump actions/checkout from 3.1.0 to 3.2.0 (#1145)
  * Bump github/codeql-action from 2.1.35 to 2.1.36 (#1143)
  * Fix typo in `mlr put` documentation (#1140)
  * Bump actions/setup-go from 3.3.1 to 3.4.0 (#1136)
  * Bump github/codeql-action from 2.1.33 to 2.1.35 (#1137)
* Wed Nov 30 2022 scott.bradnick@suse.com
- Update to version 6.5.0+git20221130.636ca8873:
  * Fix typos (#1135)
  * Release notes
  * Post-6.5.0
  * Miller 6.5.0 (#1134)
  * Miller 6.5.0
  * Convert mlrval polymorphism from struct to unionish interface (#1133)
  * Clarify locations of performance info
  * More mlrval size-reduction (#1132)
  * More mlrval size-reduction
  * Exclude median from summary default (#1131)
  * Exclude median from summary default
  * Bump github.com/stretchr/testify from 1.8.0 to 1.8.1 (#1113)
  * Bump actions/upload-artifact from 3.1.0 to 3.1.1 (#1112)
  * Bump actions/cache from 3 to 3.0.11 (#1109)
  * Bump github/codeql-action from 2.1.28 to 2.1.33 (#1126)
  * Use int8 for mvtype (memory reduction) (#1130)
  * make fmt
  * forgot to set between-releases version to 6.4.0-dev after 6.4.0
  * Bump github.com/pkg/profile from 1.6.0 to 1.7.0 (#1110)
  * [StepSecurity] ci: Harden GitHub Actions (#1107)
  * fix an old typo
* Thu Oct 13 2022 scott.bradnick@suse.com
- Renaming buildmode-pie.patch to buildmode-pie.diff
- Update to version 6.4.0+git20221003.39286923d:
  * Don't double-quote a CSV field only for having a leading space (#1101)
* Sun Oct  2 2022 scott.bradnick@suse.com
- Update to version 6.4.0+git20220929.36d0ed760:
  * type-safety in exec (#1099)
  * add source-checkout info to build-from-source instructions
  * Check -- terminator on --mfrom (#1098)
  * todo
  * mlr reshape multiple regex via multiple -r (#1091)
  * Fix labels for mlr histogram --auto (#1089)
  * Continue #1086 (#1087)
* Fri Sep  2 2022 Scott Bradnick <scott.bradnick@suse.com>
- Patch buildmode-pie.patch was added per go's request during build.
* Fri Aug 26 2022 Scott Bradnick <scott.bradnick@suse.com>
- Excluding patch from ppc64: "-buildmode=pie not supported on linux/ppc64"
* Fri Aug 26 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding Group definition
- Removing unnecessary 'golang' requirement which isn't present in 15.3
* Tue Aug 23 2022 scott.bradnick@suse.com
- Update to version v6.4.0+git20220823.cdbe8b82e:
  * Account for varying mlr locations (#1086)
  * Restore --quote-all for CSV output (#1084)
  * Restore the --jvquoteall flag (#1083)
  * forgot to make a branch/PR for --quote-all
  * make dev: for doc-build artifacts
  * unit-test case
  * Restore --quote-all flag for CSV output
  * post-6.4.0
  * 6.4.0 release (#1081)
  * codespell
* Wed Nov 17 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.10.3
  * autoreconf.fiv; manpage & docs w/ 5.10.3
  * Replace NDEBUG with MLR_DSL_NDEBUG ifdef to avoid name clash
    with conda build
  * precompute lemon artifacts
* Wed Mar 24 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.10.2
  Fix:
  * Restore mlr manpage to distro file
* Mon Mar 22 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.10.1
  Fix:
  * NR is stale after apply remove-empty-columns
  * Segfault with --tsv --implicit-csv-header
  * Default value of uninitialized variables for multiplication:
    docs vs awk
  * Bug with uniq + sort
* Mon Nov 30 2020 aloisio@gmx.com
- Update to version 5.10.0
  Features:
  * The unsparsify -f feature fulfills #387 from @sjackman .
  * The new sort-within-records verb is an old ask, underway
    from the Go port, backported to C.
  * Likewise the truncate DSL function.
  Bugfixes:
  * The count -n feature was not implemented as intended.
  * Pretty-print format now works correctly with
  - -headerless-csv-output.
  * The seqgen verb now correctly tracks NR and FNR in the
    records it emits.
  * An intermittent JSON-parsing bug has been fixed.
* Thu Sep  3 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.9.1
  * Disallow prepipe within .mlrrc (fixes CVE-2020-15167)
* Wed Aug 19 2020 aloisio@gmx.com
- Update to version 5.9.0
  * You can now save common defaults in a ~/.mlrrc. For example,
    if you normally process CSV files, you can say that in your
    ~/.mlrrc and you can leave off the --csv flag from your mlr
    commands.
* Tue Aug  4 2020 aloisio@gmx.com
- Update to version 5.8.0
  Features:
  * The new count verb is a keystroke-saver for stats -a count
  - f {some field name}`.
  * --jsonx and --ojsonx are keystroke-savers for --json
  - -jvstack and --ojson --jvstack, which is to say, multi-line
    pretty-printed JSON format.
  * The new -s name=value feature for mlr put and mlr filter
    gives you simpler access to environment variables in your
    Miller script, as requested in #315.
  Bugfixes:
  * mlr format-values is no longer SEGVing on CSV/TSV input.
    This was reported on #330.
  * #313 fixes a corner case when field names within
    command-line arguments have embedded newlines.
  * Line/column indicators for JSON-formatting error messages
    are now correct (previously they were showing up as 0).
  * end {print NF} no longer SEGVs. This was reported in #330.
  * Several broken doc links were fixed up as reported on #329.
- Drop miller-5.3.0-gcc43.patch (no longer necessary)
- Spec cleanup
* Tue Mar 17 2020 aloisio@gmx.com
- Update to version 5.7.0
  Features:
  * The new remove-empty-columns and skip-trivial-records are
    keystroke-savers for things which would other require DSL
    syntax, as tracked in #274.
  Bugfixes:
  * A bug regarding optional regex-pattern groups was fixed in
    [#277].
  * As of #294 you can now specify --implicit-csv-header for the
    join-file in mlr join.
  * A bug with spaces in XTAB-file values was fixed on #296.
  * A bug with missing final newline for XTAB-formatted files
    using MMAP files was fixed on #301.
- Drop group tag
* Sun Sep 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.6.2
  * #271 fixes a corner-case bug with more than 100 CSV/TSV files
    with headers of varying lengths.
* Fri Sep 13 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.6.0
  Features:
  * The new system DSL function allows you to run arbitrary
    shell commands and store them in field values. Some example
    usages are documented here. This is in response to issues #246
    and #209.
  * There is now support for ASV and USV file formats. This is
    in response to issue #245.
  * The new format-values verb allows you to apply numerical
    formatting across all record values. This is in response to
    issue #252.
  Documentation:
  * The new DKVP I/O in Python sample code now works for Python
    2 as well as Python 3.
  * There is a new cookbook entry on doing multiple joins. This
    is in response to issue #235.
  Bugfixes:
  * The toupper, tolower, and capitalize DSL functions are now
    UTF-8 aware, thanks to @sheredom's marvelous
    https://github.com/sheredom/utf8.h. The internationalization
    page has also been expanded. This is in response to issue #254.
  * #250 fixes a bug using in-place mode in conjunction with
    verbs (such as rename or sort) which take field-name lists as
    arguments.
  * #253 fixes a bug in the label when one or more names are
    common between old and new.
  * #251 fixes a corner-case bug when (a) input is CSV; (b) the
    last field ends with a comma and no newline; (c) input is from
    standard input and/or --no-mmap is supplied.
* Sun Sep  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.5.0
  * Positional indexing and other data-cleaning features
    Features:
  * The new positional-indexing feature resolves #236 from
    @aborruso. You can now get the name of the 3rd field of each
    record via $[[3]], and its value by $[[[3]]]. These are both
    usable on either the left-hand or right-hand side of assignment
    statements, so you can more easily do things like renaming
    fields progrmatically within the DSL.
  * There is a new capitalize DSL function, complementing the
    already-existing toupper. This stems from #236.
  * There is a new skip-trivial-records verb, resolving #197.
    Similarly, there is a new remove-empty-columns verb, resolving
    [#206]. Both are useful for data-cleaning use-cases.
  * Another pair is #181 and #256. While Miller uses mmap
    internally (and invisibily) to get approximately a 20%%
    performance boost over not using it, this can cause
    out-of-memory issues with reading either large files, or too
    many small ones. Now, Miller automatically avoids mmap in these
    cases. You can still use --mmap or --no-mmap if you want manual
    control of this.
  * There is a new --ivar option for the nest verb which
    complements the already-existing --evar. This is from #260
    thanks to @jgreely.
  * There is a new keystroke-saving urandrange DSL function:
    urandrange(low, high) is the same as low + (high - low) *
    urand().
  * There is a new -v option for the cat verb which writes a
    low-level record-structure dump to standard error.
  * There is a new -N option for mlr which is a keystroke-saver
    for --implicit-csv-header --headerless-csv-output.
  Documentation:
  * The new FAQ entry
    http://johnkerl.org/miller/doc/faq.html#How_to_escape_'%%3F'_in_re
    gexes%%3F resolves #203.
  * The new FAQ entry
    http://johnkerl.org/miller/doc/faq.html#How_can_I_filter_by_date%%
    3F resolves #208.
  * #244 fixes a documentation issue while highlighting the need
    for #241.
  Bugfixes:
  * There was a SEGV using nest within then-chains, fixed in
    response to #220.
  * Quotes and backslashes weren't being escaped in JSON output
    with --jvquoteall; reported on #222.
* Mon Oct 15 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.4.0
  Features:
  * The new clean-whitespace verb resolves #190 from @aborruso.
    Along with the new functions strip, lstrip, rstrip,
    collapse_whitespace, and clean_whitespace, there is now both
    coarse-grained and fine-grained control over whitespace
    within field names and/or values. See the linked-to
    documentation for examples.
  * The new altkv verb resolves #184 which was originally opened
    via an email request. This supports mapping value-lists such
    as a,b,c,d to alternating key-value pairs such as a=b,c=d.
  * The new fill-down verb resolves #189 by @aborruso. See the
    linked-to documentation for examples.
  * The uniq verb now has a uniq -a which resolves #168 from
    @sjackman.
  * The new regextract and regextract_or_else functions resolve
    [#183] by @aborruso.
  * The new ssub function arises from #171 by @dohse, as a
    simplified way to avoid escaping characters which are special
    to regular-expression parsers.
  * There are new localtime functions in response to #170 by
    @sitaramc. However note that as discussed on #170 these do
    not undo one another in all circumstances. This is a
    non-issue for timezones which do not do DST. Otherwise, please
    use with disclaimers: localdate, localtime2sec, sec2localdate,
    sec2localtime, strftime_local, and strptime_local.
  * Travis builds at
    https://travis-ci.org/johnkerl/miller/builds now run on OSX as
    well as Linux.
  * An Ubuntu 17 build issue was fixed by @singalen on #164.
  Documentation:
  * put/filter documentation was confusing as reported by
    @NikosAlexandris on #169.
  * The new FAQ entry
    http://johnkerl.org/miller-releases/miller-head/doc/faq.html#How_
    to_rectangularize_after_joins_with_unpaired? resolves #193 by
    @aborruso.
  * The new cookbook entry
    http://johnkerl.org/miller/doc/cookbook.html#Options_for_dealing_
    with_duplicate_rows arises from #168 from @sjackman.
  * The unsparsify documentation had some words missing as
    reported by @tst2005 on #194.
  * There was a typo in the cookpage page
    http://johnkerl.org/miller/doc/cookbook.html#Full_field_renames_a
    nd_reassigns as fixed by @tst2005 in #192.
  Bugfixes:
  * There was a memory leak for TSV-format files only as
    reported by @treynr on #181.
  * Dollar sign in regular expressions were not being escaped
    properly as reported by @dohse on #171.
* Sun Jan  7 2018 aloisio@gmx.com
- Update to version 5.3.0 (see draft-release-notes.md for a
  changelog)
- Added miller-5.3.0-gcc43.patch
* Thu Aug 24 2017 aloisio@gmx.com
- Updated license
* Thu Jul 20 2017 aloisio@gmx.com
- Update to 5.2.2
  * This bugfix release delivers a fix for #147 where a memory
    allocation failed beyond 4GB.
* Tue Jun 20 2017 aloisio@gmx.com
- Update to version 5.2.1
  * Fixes (gh#johnkerl/miller#142) build segfault on non-x86
    architectures
* Tue Jun 13 2017 aloisio@gmx.com
- Update to version 5.2.0
  This release contains mostly feature requests.
  Features:
  * The stats1 verb now lets you use regular expressions to
    specify which field names to compute statistics on, and/or which
    to group by. Full details are here.
  * The min and max DSL functions, and the min/max/percentile
    aggregators for the stats1 and merge-fields verbs, now support
    numeric as well as string field values. (For mixed string/numeric
    fields, numbers compare before strings.) This means in particular
    that order statistics -- min, max, and non-interpolated
    percentiles -- as well as mode, antimode, and count are now
    possible on string-only fields. (Of course, any operations
    requiring arithmetic on values, such as computing sums, averages,
    or interpolated percentiles, yield an error on string-valued
    input.)
  * There is a new DSL function mapexcept which returns a copy of
    the argument with specified key(s), if any, unset. The motivating
    use-case is to split records to multiple filenames depending on
    particular field value, which is omitted from the output: mlr
  - -from f.dat put 'tee > "/tmp/data-".$a, mapexcept($*, "a")'
    Likewise, mapselect returns a copy of the argument with only
    specified key(s), if any, set. This resolves #137.
  * A new -u option for count-distinct allows unlashed counts for
    multiple field names. For example, with -f a,b and without -u,
    count-distinct computes counts for distinct pairs of a and b field
    values. With -f a,b and with -u, it computes counts for distinct a
    field values and counts for distinct b field values separately.
  * If you build from source, you can now do ./configure without
    first doing autoreconf -fiv. This resolves #131.
  * The UTF-8 BOM sequence 0xef 0xbb 0xbf is now automatically
    ignored from the start of CSV files. (The same is already done for
    JSON files.) This resolves #138.
  * For put and filter with -S, program literals such as the 6 in
    $x = 6 were being parsed as strings. This is not sensible, since
    the -S option for put and filter is intended to suppress numeric
    conversion of record data, not program literals. To get string 6
    one may use $x = "6".
  Documentation:
  * A new cookbook example shows how to compute differences
    between successive queries, e.g. to find out what changed in
    time-varying data when you run and rerun a SQL query.
  * Another new cookbook example shows how to compute
    interquartile ranges.
  * A third new cookbook example shows how to compute weighted
    means.
  Bugfixes:
  * CRLF line-endings were not being correctly autodetected when
    I/O formats were specified using --c2j et al.
  * Integer division by zero was causing a fatal runtime
    exception, rather than computing inf or nan as in the
    floating-point case.
* Sat Apr 15 2017 aloisio@gmx.com
- Update to 5.1.0 (see changelog at
  https://github.com/johnkerl/miller/releases/tag/v5.1.0)
* Sun Mar 12 2017 aloisio@gmx.com
- Update to version 5.0.1
  Minor bugfixes:
  * As described in #132, mlr nest was incorrectly splitting
    fields with multi-character separators.
  * The XTAB-format reader, when using multi-character IPS,
    was incorrectly splitting key-value pairs, but only when
    reading from standard input (e.g. on a pipe or less-than
    redirect).
* Tue Feb 28 2017 aloisio@gmx.com
- Initial package (v5.0.0)
